/*
 * This file is part of XViewdata - a viewdata terminal emulator.
 * Copyright (C) 1997 Peter Corlett. All Rights Reserved.
 *
 * ConnectionDriver.cc - Implementation of a generic Server driver
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "../config.h"

#include <unistd.h>

#include "global.h"
#include "ConnectionDriver.h"
#ifdef USE_SERIAL
#include "Serial.h"
#endif
#ifdef USE_TELNET
#include "Telnet.h"
#endif

struct ConnectionDrivers ConnectionDrivers[] = {
#ifdef USE_SERIAL
  {"serial", (ConnectionDriver *(*)(String &))newSerial},
#endif
#ifdef USE_TELNET
  {"telnet", (ConnectionDriver *(*)(String &))newTelnet},
#endif
  {NULL}
};

void ConnectionDriver::clear() {
  POFUNC;
}

void ConnectionDriver::free() {
  POFUNC;
  clear();
}

ConnectionDriver::ConnectionDriver(void) {
  POFUNC;
  clear();
}

ConnectionDriver::~ConnectionDriver() {
  POFUNC;
  free();
}

ConnectionDriver *newConnectionDriver(const String &type, const String &path) return d {
  PGFUNC;
  D("trying to open Server type \"" << type << "\" to \"" << path << "\"");
  d=NULL;

  for(int n=0;ConnectionDrivers[n].name&&!d;n++)
    if(!fcompare(type, ConnectionDrivers[n].name))
      if(ConnectionDrivers[n].newobject) {
	d=(*ConnectionDrivers[n].newobject)(path);
      }

  if(!d)
    return;

}

