/*
 * This file is part of XViewdata - a viewdata terminal emulator.
 * Copyright (C) 1997 Peter Corlett. All Rights Reserved.
 *
 * Serial.h - prototypes for TCP/IP stream driver
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#ifndef SERIAL_H
#define SERIAL_H

#ifdef USE_SERIAL

#include "ConnectionDriver.h"
#include <String.h>

/// Makes TCP/IP connections
class Serial : public ConnectionDriver {
  ///
  void clear(void);
  ///
  void free(void);

  /// FD of serial port
  int sock;

  ///
public:
  /// Default constructor.
  Serial(void);
  /// Destructor.
  ~Serial();

  /** Creates a new Serial object with the appropriate attributes.
    @param dx width of display in pixels.
    @param dy height of display in pixels.
    @return NULL on failure, pointer to new TTYDisplay object otherwise.
    */
  friend Serial *newSerial(String &path);

  /// (see ConnectionDriver)
  int write(const char *, int);
  /// (see ConnectionDriver)
  int read(char *, int);
  /// (see ConnectionDriver)
  int getUnderlyingFD(void) {POFUNC; return sock;};
};

#endif /* USE_SERIAL */

#endif /* SERIAL_H */
